k8s\.models\.custom\_resource\_definition module
================================================

.. automodule:: k8s.models.custom_resource_definition
    :members:
    :undoc-members:
    :show-inheritance:
